"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.awsCli = exports.execWithCli = exports.execWithDocker = exports.assertAwsCli = exports.hasAwsCli = void 0;
const utils_sh_1 = require("@goldstack/utils-sh");
const infra_aws_1 = require("@goldstack/infra-aws");
const utils_log_1 = require("@goldstack/utils-log");
const utils_docker_1 = require("@goldstack/utils-docker");
const hasAwsCli = () => {
    return (0, utils_sh_1.commandExists)('aws');
};
exports.hasAwsCli = hasAwsCli;
const assertAwsCli = () => {
    if (!(0, utils_sh_1.commandExists)('aws')) {
        (0, utils_log_1.fatal)('AWS CLI version 2 not available.\n\nEnsure AWS cli or Docker (preferred) are available commands in the command line.');
        throw new Error();
    }
    const version = (0, utils_sh_1.exec)('aws --version', { silent: true });
    if (version.indexOf('aws-cli/2.') <= -1) {
        (0, utils_log_1.fatal)(`Wrong AWS cli version installed. Expected version 2 but found version '${version}'` +
            '\n\nEither install AWS cli or Docker.');
        throw new Error();
    }
};
exports.assertAwsCli = assertAwsCli;
const execWithDocker = async (params) => {
    (0, utils_docker_1.assertDocker)();
    const credentials = await (0, infra_aws_1.getAWSCredentials)(params.credentials);
    const awsUserConfig = `-e AWS_ACCESS_KEY_ID=${credentials.accessKeyId} ` +
        `-e AWS_SECRET_ACCESS_KEY=${credentials.secretAccessKey} ` +
        `-e AWS_SESSION_TOKEN=${credentials.sessionToken || ''} ` +
        `-e AWS_DEFAULT_REGION=${params.region} `;
    const mountDir = params.workDir || (0, utils_sh_1.pwd)();
    (0, utils_sh_1.assertDirectoryExists)(mountDir, 'Cannot execute AWS cli command since working directory does not exist: aws ' +
        params.command);
    const command = 'docker run --rm ' +
        awsUserConfig +
        `-v "${mountDir}":/app ` +
        '-w /app ' +
        ` ${(0, utils_docker_1.imageAWSCli)()} ${params.command}`;
    return (0, utils_sh_1.execAsync)(command, params.options);
};
exports.execWithDocker = execWithDocker;
const execWithCli = async (params) => {
    (0, exports.assertAwsCli)();
    const credentials = await (0, infra_aws_1.getAWSCredentials)(params.credentials);
    process.env.AWS_ACCESS_KEY_ID = credentials.accessKeyId;
    process.env.AWS_SECRET_ACCESS_KEY = credentials.secretAccessKey;
    process.env.AWS_SESSION_TOKEN = credentials.sessionToken || '';
    process.env.AWS_DEFAULT_REGION = params.region;
    (0, utils_sh_1.assertDirectoryExists)(params.workDir || (0, utils_sh_1.pwd)(), 'Cannot execute command for AWS cli: aws ' + params.command);
    const previousDir = (0, utils_sh_1.pwd)();
    (0, utils_sh_1.cd)(params.workDir || (0, utils_sh_1.pwd)());
    try {
        const command = `aws ${params.command}`;
        (0, utils_log_1.debug)(`AWS command to be executed:\n  aws ${params.command}`);
        return await (0, utils_sh_1.execAsync)(command, params.options);
    }
    finally {
        (0, utils_sh_1.cd)(previousDir);
    }
};
exports.execWithCli = execWithCli;
const awsCli = async (params) => {
    if ((0, exports.hasAwsCli)()) {
        return (0, exports.execWithCli)(params);
    }
    if (!(0, utils_docker_1.hasDocker)()) {
        (0, utils_log_1.fatal)('AWS CLI version 2 not available.\n\nEnsure AWS cli (preferred) or Docker are available commands in the command line.');
    }
    return (0, exports.execWithDocker)(params);
};
exports.awsCli = awsCli;
//# sourceMappingURL=utilsAwsCli.js.map